openclean\_notebook.controller.spreadsheet.data module
======================================================

.. automodule:: openclean_notebook.controller.spreadsheet.data
   :members:
   :undoc-members:
   :show-inheritance:
